@@ -709,7 +709,7 @@ my $standup_catalyst=sub {
    if (exists $main::aws->{'CatalystFramework.org'}) {
       my $g=get_aws_security_id('CatalystSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'CatalystFramework.org'}}==0) {
 #print "WTF is DISPLAY=$DISPLAY\n";
