@@ -953,7 +953,7 @@ my $standup_clipbucket=sub {
    if (exists $main::aws->{'CLIPBUCKET'}) {
       my $g=get_aws_security_id('ClipBucketSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'CLIPBUCKET'}}==0) {
          launch_server('CLIPBUCKET',$cnt,$clipbucket,'',$c,
