@@ -988,7 +988,7 @@ my $standup_gnusocial=sub {
    if (exists $main::aws->{'GNU.io/Social'}) {
       my $g=get_aws_security_id('GNUSocialSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'GNU.io/Social'}}==0) {
          launch_server('GNU.io/Social',$cnt,$gnusocial,'',$c,
