@@ -204,7 +204,7 @@ END
    }
    use Cwd;
    ($stdout,$stderr)=$sftp_handle->cmd(
-      "put ".cwd()."/$pem_file",'__display__');
+      "put '".cwd()."/$pem_file"."'",'__display__');
    $handle->{_cmd_handle}->print('eval `ssh-agent -s`');
    my $prompt=substr($handle->{_cmd_handle}->prompt(),1,-1);
    while (1) {
@@ -214,7 +214,7 @@ END
    }
    ($stdout,$stderr)=$handle->cmd('pwd');
    $handle->{_cmd_handle}->print(
-      "ssh-add $stdout/$pem_file");
+      "ssh-add \'$stdout/$pem_file\'");
    while (1) {
       my $output=Net::FullAuto::FA_Core::fetch($handle);
       last if $output=~/$prompt/;
@@ -478,7 +478,7 @@ my $standup_hadoop=sub {
    if (exists $main::aws->{'Hadoop.Apache.org'}) {
       my $g=get_aws_security_id('HadoopSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'Hadoop.Apache.org'}}==0) {
          launch_server('Hadoop.Apache.org',$cnt,$hadoop,$u,$c,
