@@ -222,7 +222,7 @@ my $standup_kali_linux=sub {
    if (exists $main::aws->{'Kali.org'}) {
       my $g=get_aws_security_id('KaliLinuxSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'Kali.org'}}==0) {
          launch_server('Kali.org',$cnt,$kali,$u,$c,$configure_kalilinux);
