@@ -310,7 +310,7 @@ my $standup_openldap=sub {
    if (exists $main::aws->{'OpenLDAP.org'}) {
       my $g=get_aws_security_id('OpenLDAPSecurityGroup');
       my $c="aws ec2 run-instances --image-id $i --count 1 ".
-         "--instance-type $type --key-name $pemfile ".
+         "--instance-type $type --key-name \'$pemfile\' ".
          "--security-group-ids $g --subnet-id $s";
       if ($#{$main::aws->{'OpenLDAP.org'}}==0) {
          launch_server('OpenLDAP.org',$cnt,$openldap,'',$c,
